/*
https://docs.nestjs.com/providers#services
*/

import { Injectable, UnauthorizedException } from '@nestjs/common';
import { User } from '../../domain/user';
import { UserToken, UserPayload } from './models/user-auth';
import { JwtService } from '@nestjs/jwt';
import { UserService } from '../user/user.service';
import { UserDocument } from 'src/database/schemas/user.schema';
import { EncryptorService } from 'src/security/encryptor.service';

@Injectable()
export class AuthService {
  constructor(
    private readonly userService: UserService,
    private readonly jwtService: JwtService,
    private readonly encryptorService: EncryptorService,
  ) {}

  async login(user: User): Promise<UserToken> {
    const payload: UserPayload = {
      sub: user.cpf,
    };
    const jwtToken = this.jwtService.sign(payload);
    return {
      access_token: jwtToken,
    };
  }

  async validateUser(cpf: string, password: string): Promise<UserDocument> {
    const userFromDb = await this.userService.findByCpf(cpf);
    if (userFromDb) {
      const isValidPassword = await this.encryptorService.comparePassword(
        password,
        userFromDb.password,
      );
      if (isValidPassword) {
        return { ...userFromDb, password: undefined };
      }
    }
    throw new UnauthorizedException('CPF e/ou senha invalidos.');
  }
}
