import { Prop, Schema, SchemaFactory } from '@nestjs/mongoose';
import { Contact } from '../../domain/contact';
import { User as IUser } from '../../domain/user';
import { Address } from './address.schema';

export type UserDocument = User & Document;
export type UserEntity = User & { _id: string };

@Schema()
export class User implements IUser {
  @Prop({ required: true })
  nome: string;

  @Prop({ required: true })
  password: string;

  @Prop({ required: true })
  cpf: string;

  @Prop({ required: true })
  telefone: string;

  @Prop({ required: true })
  email: string;

  @Prop()
  numeroINSS?: string;

  @Prop()
  planoDeSaude?: string;

  @Prop(Address)
  endereco?: Address;

  @Prop()
  medicamentos?: string;

  @Prop({ required: true })
  contatosProfissionais: Contact[];

  @Prop({ required: true })
  contatoEmergencia: string;

  @Prop({ required: true })
  administrador: boolean;
}

export type UserCreate = Omit<User, '_id'>;

export const UserSchema = SchemaFactory.createForClass(User);
